using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.IO;
using CADImport;
using CADImport.CADImportForms;

namespace CADImportNetDemos.CADMergeFilesDemo
{
	#region Help
	/// <summary>
	/// Represents a form in which a file to be merged can be selected and parameters of merging can be set.
	/// </summary>
	#endregion Help
	public class MergeForm : System.Windows.Forms.Form
	{
		private CADImage image;	
		private ArrayList filesToMerge;		
		private int prevIndex;

		#region Help
		/// <summary>
		/// Invokes on Image dimensions changing
		/// </summary>
		#endregion
		public event CADImport.FaceModule.CADImportEventHandler ResizeEvent;

		private System.Windows.Forms.Panel pnTools;
		private System.Windows.Forms.Button btnOpenNext;
		private System.Windows.Forms.ComboBox cbFiles;
		private System.Windows.Forms.Label lbFiles;
		private System.Windows.Forms.Button btnDefaultVal;
		private System.Windows.Forms.Label lbRotation;
		private System.Windows.Forms.NumericUpDown numRotation;
		private System.Windows.Forms.GroupBox grbScale;
		private System.Windows.Forms.NumericUpDown numXsc;
		private System.Windows.Forms.NumericUpDown numYsc;
		private System.Windows.Forms.NumericUpDown numZsc;
		private System.Windows.Forms.GroupBox grbPosition;
		private System.Windows.Forms.Label lbZ;
		private System.Windows.Forms.Label lbY;
		private System.Windows.Forms.NumericUpDown numZ;
		private System.Windows.Forms.NumericUpDown numY;
		private System.Windows.Forms.NumericUpDown numX;
		private System.Windows.Forms.Label lbX;
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.Label lbCnFiles;
		private System.Windows.Forms.Label lbPercent3;
		private System.Windows.Forms.Label lbPercent2;
		private System.Windows.Forms.Label lbScZ;
		private System.Windows.Forms.Label lbScY;
		private System.Windows.Forms.Label lbScX;
		private System.Windows.Forms.Label lbPercent1;
		private System.Windows.Forms.OpenFileDialog dlgOpenFile;		
		
		#region Help
		/// <summary>
		/// Invokes <see cref="MergeForm.ResizeEvent"/>ResizeEvent event
		/// </summary>
		#endregion
		public void OnResize()
		{
			if (ResizeEvent != null)
				ResizeEvent();
		}

		#region Help
		/// <summary>
		/// Gets or sets <see cref="CADImport.CADImage">CADImage</see> object where new entities are added
		/// </summary>
		#endregion
		public CADImage Image
		{
			get
			{
				return this.image;
			}
			set
			{
				this.image = value;
			}
		}
		
		private System.ComponentModel.Container components = null;

		#region Help
		/// <summary>
		/// Initializes a new instance of the <see cref="MergeForm">MergeForm</see> class.
		/// </summary>
		#endregion Help
		public MergeForm()
		{
			InitializeComponent();
			InitExtParam();
		}

		private void InitExtParam()
		{			
			filesToMerge = new ArrayList();			
			prevIndex = -1;
		}

		#region Help
		/// <summary>
		/// Cleans up any resources being used.
		/// </summary>
		/// <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
		///</param>
		#endregion Help
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.pnTools = new System.Windows.Forms.Panel();
			this.btnOpenNext = new System.Windows.Forms.Button();
			this.cbFiles = new System.Windows.Forms.ComboBox();
			this.lbCnFiles = new System.Windows.Forms.Label();
			this.lbFiles = new System.Windows.Forms.Label();
			this.btnDefaultVal = new System.Windows.Forms.Button();
			this.lbRotation = new System.Windows.Forms.Label();
			this.numRotation = new System.Windows.Forms.NumericUpDown();
			this.grbScale = new System.Windows.Forms.GroupBox();
			this.lbPercent3 = new System.Windows.Forms.Label();
			this.lbPercent2 = new System.Windows.Forms.Label();
			this.lbScZ = new System.Windows.Forms.Label();
			this.lbScY = new System.Windows.Forms.Label();
			this.numXsc = new System.Windows.Forms.NumericUpDown();
			this.numYsc = new System.Windows.Forms.NumericUpDown();
			this.numZsc = new System.Windows.Forms.NumericUpDown();
			this.lbScX = new System.Windows.Forms.Label();
			this.lbPercent1 = new System.Windows.Forms.Label();
			this.grbPosition = new System.Windows.Forms.GroupBox();
			this.lbZ = new System.Windows.Forms.Label();
			this.lbY = new System.Windows.Forms.Label();
			this.numZ = new System.Windows.Forms.NumericUpDown();
			this.numY = new System.Windows.Forms.NumericUpDown();
			this.numX = new System.Windows.Forms.NumericUpDown();
			this.lbX = new System.Windows.Forms.Label();
			this.btnOK = new System.Windows.Forms.Button();
			this.dlgOpenFile = new System.Windows.Forms.OpenFileDialog();
			this.pnTools.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numRotation)).BeginInit();
			this.grbScale.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numXsc)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numYsc)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numZsc)).BeginInit();
			this.grbPosition.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numZ)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numY)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numX)).BeginInit();
			this.SuspendLayout();
			// 
			// pnTools
			// 
			this.pnTools.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
			this.pnTools.Controls.Add(this.btnOpenNext);
			this.pnTools.Controls.Add(this.cbFiles);
			this.pnTools.Controls.Add(this.lbCnFiles);
			this.pnTools.Controls.Add(this.lbFiles);
			this.pnTools.Controls.Add(this.btnDefaultVal);
			this.pnTools.Controls.Add(this.lbRotation);
			this.pnTools.Controls.Add(this.numRotation);
			this.pnTools.Controls.Add(this.grbScale);
			this.pnTools.Controls.Add(this.grbPosition);
			this.pnTools.Location = new System.Drawing.Point(0, 0);
			this.pnTools.Name = "pnTools";
			this.pnTools.Size = new System.Drawing.Size(242, 246);
			this.pnTools.TabIndex = 0;
			// 
			// btnOpenNext
			// 
			this.btnOpenNext.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnOpenNext.Location = new System.Drawing.Point(142, 213);
			this.btnOpenNext.Name = "btnOpenNext";
			this.btnOpenNext.Size = new System.Drawing.Size(88, 24);
			this.btnOpenNext.TabIndex = 11;
			this.btnOpenNext.Text = "Open next file";
			this.btnOpenNext.Click += new System.EventHandler(this.btnOpenNext_Click);
			// 
			// cbFiles
			// 
			this.cbFiles.Location = new System.Drawing.Point(8, 184);
			this.cbFiles.Name = "cbFiles";
			this.cbFiles.Size = new System.Drawing.Size(224, 21);
			this.cbFiles.TabIndex = 10;
			this.cbFiles.SelectedValueChanged += new System.EventHandler(this.cbFiles_SelectedValueChanged);
			// 
			// lbCnFiles
			// 
			this.lbCnFiles.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.lbCnFiles.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbCnFiles.Location = new System.Drawing.Point(200, 161);
			this.lbCnFiles.Name = "lbCnFiles";
			this.lbCnFiles.Size = new System.Drawing.Size(25, 16);
			this.lbCnFiles.TabIndex = 9;
			this.lbCnFiles.Text = "0";
			this.lbCnFiles.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// lbFiles
			// 
			this.lbFiles.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.lbFiles.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbFiles.Location = new System.Drawing.Point(8, 160);
			this.lbFiles.Name = "lbFiles";
			this.lbFiles.Size = new System.Drawing.Size(184, 16);
			this.lbFiles.TabIndex = 8;
			this.lbFiles.Text = "Number of files to be merged :";
			// 
			// btnDefaultVal
			// 
			this.btnDefaultVal.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnDefaultVal.Location = new System.Drawing.Point(142, 126);
			this.btnDefaultVal.Name = "btnDefaultVal";
			this.btnDefaultVal.Size = new System.Drawing.Size(88, 24);
			this.btnDefaultVal.TabIndex = 7;
			this.btnDefaultVal.Text = "Default values";
			this.btnDefaultVal.Click += new System.EventHandler(this.btnDefaultVal_Click);
			// 
			// lbRotation
			// 
			this.lbRotation.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.lbRotation.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbRotation.Location = new System.Drawing.Point(0, 126);
			this.lbRotation.Name = "lbRotation";
			this.lbRotation.Size = new System.Drawing.Size(64, 23);
			this.lbRotation.TabIndex = 6;
			this.lbRotation.Text = "Rotation :";
			this.lbRotation.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// numRotation
			// 
			this.numRotation.Location = new System.Drawing.Point(64, 128);
			this.numRotation.Maximum = new System.Decimal(new int[] {
																		100000,
																		0,
																		0,
																		0});
			this.numRotation.Minimum = new System.Decimal(new int[] {
																		100000,
																		0,
																		0,
																		-2147483648});
			this.numRotation.Name = "numRotation";
			this.numRotation.Size = new System.Drawing.Size(56, 20);
			this.numRotation.TabIndex = 5;
			// 
			// grbScale
			// 
			this.grbScale.Controls.Add(this.lbPercent3);
			this.grbScale.Controls.Add(this.lbPercent2);
			this.grbScale.Controls.Add(this.lbScZ);
			this.grbScale.Controls.Add(this.lbScY);
			this.grbScale.Controls.Add(this.numXsc);
			this.grbScale.Controls.Add(this.numYsc);
			this.grbScale.Controls.Add(this.numZsc);
			this.grbScale.Controls.Add(this.lbScX);
			this.grbScale.Controls.Add(this.lbPercent1);
			this.grbScale.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.grbScale.Location = new System.Drawing.Point(128, 8);
			this.grbScale.Name = "grbScale";
			this.grbScale.Size = new System.Drawing.Size(104, 104);
			this.grbScale.TabIndex = 1;
			this.grbScale.TabStop = false;
			this.grbScale.Text = "Scale";
			// 
			// lbPercent3
			// 
			this.lbPercent3.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbPercent3.Location = new System.Drawing.Point(80, 81);
			this.lbPercent3.Name = "lbPercent3";
			this.lbPercent3.Size = new System.Drawing.Size(16, 16);
			this.lbPercent3.TabIndex = 8;
			this.lbPercent3.Text = "%";
			this.lbPercent3.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lbPercent2
			// 
			this.lbPercent2.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbPercent2.Location = new System.Drawing.Point(80, 51);
			this.lbPercent2.Name = "lbPercent2";
			this.lbPercent2.Size = new System.Drawing.Size(16, 16);
			this.lbPercent2.TabIndex = 7;
			this.lbPercent2.Text = "%";
			this.lbPercent2.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lbScZ
			// 
			this.lbScZ.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbScZ.Location = new System.Drawing.Point(8, 80);
			this.lbScZ.Name = "lbScZ";
			this.lbScZ.Size = new System.Drawing.Size(24, 16);
			this.lbScZ.TabIndex = 6;
			this.lbScZ.Text = "Z :";
			this.lbScZ.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lbScY
			// 
			this.lbScY.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbScY.Location = new System.Drawing.Point(8, 51);
			this.lbScY.Name = "lbScY";
			this.lbScY.Size = new System.Drawing.Size(24, 16);
			this.lbScY.TabIndex = 5;
			this.lbScY.Text = "Y :";
			this.lbScY.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// numXsc
			// 
			this.numXsc.Location = new System.Drawing.Point(32, 20);
			this.numXsc.Maximum = new System.Decimal(new int[] {
																   1000,
																   0,
																   0,
																   0});
			this.numXsc.Name = "numXsc";
			this.numXsc.Size = new System.Drawing.Size(48, 20);
			this.numXsc.TabIndex = 4;
			this.numXsc.Value = new System.Decimal(new int[] {
																 100,
																 0,
																 0,
																 0});
			// 
			// numYsc
			// 
			this.numYsc.Location = new System.Drawing.Point(32, 49);
			this.numYsc.Maximum = new System.Decimal(new int[] {
																   1000,
																   0,
																   0,
																   0});
			this.numYsc.Name = "numYsc";
			this.numYsc.Size = new System.Drawing.Size(48, 20);
			this.numYsc.TabIndex = 3;
			this.numYsc.Value = new System.Decimal(new int[] {
																 100,
																 0,
																 0,
																 0});
			// 
			// numZsc
			// 
			this.numZsc.Location = new System.Drawing.Point(32, 78);
			this.numZsc.Maximum = new System.Decimal(new int[] {
																   1000,
																   0,
																   0,
																   0});
			this.numZsc.Name = "numZsc";
			this.numZsc.Size = new System.Drawing.Size(48, 20);
			this.numZsc.TabIndex = 2;
			this.numZsc.Value = new System.Decimal(new int[] {
																 100,
																 0,
																 0,
																 0});
			// 
			// lbScX
			// 
			this.lbScX.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbScX.Location = new System.Drawing.Point(8, 22);
			this.lbScX.Name = "lbScX";
			this.lbScX.Size = new System.Drawing.Size(24, 16);
			this.lbScX.TabIndex = 1;
			this.lbScX.Text = "X :";
			this.lbScX.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lbPercent1
			// 
			this.lbPercent1.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbPercent1.Location = new System.Drawing.Point(80, 23);
			this.lbPercent1.Name = "lbPercent1";
			this.lbPercent1.Size = new System.Drawing.Size(16, 16);
			this.lbPercent1.TabIndex = 2;
			this.lbPercent1.Text = "%";
			this.lbPercent1.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// grbPosition
			// 
			this.grbPosition.Controls.Add(this.lbZ);
			this.grbPosition.Controls.Add(this.lbY);
			this.grbPosition.Controls.Add(this.numZ);
			this.grbPosition.Controls.Add(this.numY);
			this.grbPosition.Controls.Add(this.numX);
			this.grbPosition.Controls.Add(this.lbX);
			this.grbPosition.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.grbPosition.Location = new System.Drawing.Point(8, 8);
			this.grbPosition.Name = "grbPosition";
			this.grbPosition.Size = new System.Drawing.Size(112, 104);
			this.grbPosition.TabIndex = 0;
			this.grbPosition.TabStop = false;
			this.grbPosition.Text = "Position";
			// 
			// lbZ
			// 
			this.lbZ.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbZ.Location = new System.Drawing.Point(8, 80);
			this.lbZ.Name = "lbZ";
			this.lbZ.Size = new System.Drawing.Size(24, 16);
			this.lbZ.TabIndex = 6;
			this.lbZ.Text = "Z :";
			this.lbZ.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// lbY
			// 
			this.lbY.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbY.Location = new System.Drawing.Point(8, 51);
			this.lbY.Name = "lbY";
			this.lbY.Size = new System.Drawing.Size(24, 16);
			this.lbY.TabIndex = 5;
			this.lbY.Text = "Y :";
			this.lbY.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// numZ
			// 
			this.numZ.Location = new System.Drawing.Point(32, 78);
			this.numZ.Maximum = new System.Decimal(new int[] {
																 100000,
																 0,
																 0,
																 0});
			this.numZ.Minimum = new System.Decimal(new int[] {
																 100000,
																 0,
																 0,
																 -2147483648});
			this.numZ.Name = "numZ";
			this.numZ.Size = new System.Drawing.Size(72, 20);
			this.numZ.TabIndex = 4;
			// 
			// numY
			// 
			this.numY.Location = new System.Drawing.Point(32, 49);
			this.numY.Maximum = new System.Decimal(new int[] {
																 100000,
																 0,
																 0,
																 0});
			this.numY.Minimum = new System.Decimal(new int[] {
																 100000,
																 0,
																 0,
																 -2147483648});
			this.numY.Name = "numY";
			this.numY.Size = new System.Drawing.Size(72, 20);
			this.numY.TabIndex = 3;
			// 
			// numX
			// 
			this.numX.Location = new System.Drawing.Point(32, 20);
			this.numX.Maximum = new System.Decimal(new int[] {
																 100000,
																 0,
																 0,
																 0});
			this.numX.Minimum = new System.Decimal(new int[] {
																 100000,
																 0,
																 0,
																 -2147483648});
			this.numX.Name = "numX";
			this.numX.Size = new System.Drawing.Size(72, 20);
			this.numX.TabIndex = 2;
			// 
			// lbX
			// 
			this.lbX.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.lbX.Location = new System.Drawing.Point(8, 22);
			this.lbX.Name = "lbX";
			this.lbX.Size = new System.Drawing.Size(24, 16);
			this.lbX.TabIndex = 1;
			this.lbX.Text = "X :";
			this.lbX.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// btnOK
			// 
			this.btnOK.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnOK.Location = new System.Drawing.Point(142, 250);
			this.btnOK.Name = "btnOK";
			this.btnOK.Size = new System.Drawing.Size(88, 24);
			this.btnOK.TabIndex = 3;
			this.btnOK.Text = "OK";
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			// 
			// dlgOpenFile
			// 
			this.dlgOpenFile.Filter = "AutoCAD files(*.dwg;*.dxf)|*.dwg;*.dxf";
			// 
			// MergeForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(242, 277);
			this.Controls.Add(this.btnOK);
			this.Controls.Add(this.pnTools);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "MergeForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Merge Scaled Files";
			this.pnTools.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numRotation)).EndInit();
			this.grbScale.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numXsc)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numYsc)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numZsc)).EndInit();
			this.grbPosition.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numZ)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numY)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numX)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		private string GetFileName(string path)
		{			
			return Path.GetFileName(path);						
		}
		
		private CADImage CreateCADImage(FileRecord rec)
		{
			CADImage img = CADImage.CreateImageByExtension(rec.FileName);
			if(img == null)
				return null;
			img.LoadFromFile(rec.FileName);			
			img.UseDoubleBuffering = false;
			img.BackgroundColor = this.image.BackgroundColor;
			img.DefaultColor = image.DefaultColor;
			img.DrawMode = image.DrawMode;
			return img;
		}

		private void btnOK_Click(object sender, System.EventArgs e) 
		{			
			CADImage img1;
			if(filesToMerge.Count > 0)
			{				
				for(int i = 0; i < filesToMerge.Count; i++)
				{
					FileRecord f1 = (FileRecord)filesToMerge[i];
					img1 = CreateCADImage(f1);
					image.AddScaledDXF(img1, f1.FileName, f1.Position, f1.Scale, (float)f1.Rotation);					
					this.OnResize();
				}				
				Image.GetExtents();												
			}
			this.Close();
		}

		private void btnDefaultVal_Click(object sender, System.EventArgs e)
		{
			foreach(Control control in this.grbPosition.Controls)
			{
				if(control is NumericUpDown)
					control.Text = ApplicationConstants.zerostr;
			}
			foreach(Control control in this.grbScale.Controls)
			{
				if(control is NumericUpDown)
					control.Text = ApplicationConstants.hundredstr;
			}
			foreach(Control control in this.pnTools.Controls)
			{
				if(control is NumericUpDown)
					control.Text = ApplicationConstants.zerostr;
			}
		}

		private void btnOpenNext_Click(object sender, System.EventArgs e)
		{
			if(dlgOpenFile.ShowDialog() == DialogResult.OK)
			{
				DPoint pos = new DPoint((double)numX.Value, (double)numY.Value, (double)numZ.Value);
				DPoint scPt = new DPoint((double)numXsc.Value / 100.0, (double)numYsc.Value / 100.0, (double)numZsc.Value / 100.0);
				FileRecord f1 = new FileRecord(dlgOpenFile.FileName, pos, scPt, (float)numRotation.Value); 
				filesToMerge.Add(f1);
				this.cbFiles.Items.Add(string.Format("{0}. {1}", this.cbFiles.Items.Count, GetFileName(dlgOpenFile.FileName)));
				this.cbFiles.SelectedItem = this.cbFiles.Items[this.cbFiles.Items.Count - 1];
			}
		}

		private void cbFiles_SelectedValueChanged(object sender, System.EventArgs e)
		{			
			lbCnFiles.Text = filesToMerge.Count.ToString();
			FileRecord f1 = (FileRecord)filesToMerge[cbFiles.SelectedIndex];
			this.numX.Value = (decimal)f1.Position.X;
			this.numY.Value = (decimal)f1.Position.Y;
			this.numZ.Value = (decimal)f1.Position.Z;
			this.numXsc.Value = (decimal)(f1.Scale.X * 100.0);
			this.numYsc.Value = (decimal)(f1.Scale.Y * 100.0);
			this.numZsc.Value = (decimal)(f1.Scale.Z * 100.0);
			this.numRotation.Value = (decimal) f1.Rotation;
			prevIndex = this.cbFiles.SelectedIndex;
		}
	}

	#region Help
	/// <summary>
	/// Represents a record that contains information about the file to be merged.
	/// </summary>
	#endregion Help
	public class FileRecord
	{
		private string fileName;
		private DPoint position;
		private DPoint scale;
		private float rotation;

		#region Help
		/// <summary>
		/// Gets or sets a name of the file to be merged.
		/// </summary>
		/// <value>A <b>string</b> containing a name of the file to be merged.</value>
		#endregion Help
		public string FileName
		{
			get
			{
				return fileName;
			}
			set
			{
				fileName = value;
			}
		}

		#region Help
		/// <summary>
		/// Gets or sets a position of the CAD image from the file to be merged.
		/// </summary>
		/// <value>A <see cref="CADImport.DPoint">DPoint</see> object 
		/// representing a position of the CAD image from the file to be merged.</value>
		#endregion Help
		public DPoint Position
		{
			get
			{
				return position;
			}
			set
			{
				position = value;
			}
		}

		#region Help
		/// <summary>
		/// Gets or sets a scale of the CAD image from the file to be merged.
		/// </summary>
		/// <value>A <see cref="CADImport.DPoint">DPoint</see> object representing 
		/// a scale of the CAD image from the file to be merged.</value>
		#endregion Help
		public DPoint Scale
		{
			get
			{
				return scale;
			}
			set
			{
				scale = value;
			}
		}

		#region Help
		/// <summary>
		/// Gets or sets a rotation angle of the CAD image from the file to be merged.
		/// </summary>
		#endregion Help
		public float Rotation
		{
			get
			{
				return rotation;
			}
			set
			{
				rotation = value;
			}
		}

		#region Help
		/// <summary>
		/// Initializes a new instance of the <see cref="FileRecord">FileRecord</see> class.
		/// </summary>
		/// <param name="fileName">A <b>string</b> containing a name of the file to be merged.</param>
		/// <param name="position">A <see cref="CADImport.DPoint">DPoint</see> object 
		/// representing a position of the CAD image from the file to be merged.</param>
		/// <param name="scale">A <see cref="CADImport.DPoint">DPoint</see> object representing 
		/// a scale of the CAD image from the file to be merged.</param>
		/// <param name="rotation">A rotation angle of the CAD image from the file to be merged.</param>
		#endregion Help
		public FileRecord(string fileName, DPoint position, DPoint scale, float rotation)
		{		
			this.fileName = fileName;
			this.position = position;
			this.scale = scale;
			this.rotation = rotation;
		}
	}
}
